#
# spec file for package zanshin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0
%define kpim6_version 6.4.0

%bcond_without released
Name:           zanshin
Version:        25.04.0
Release:        1.1
Summary:        TODO Application
License:        GPL-2.0-only
URL:            https://zanshin.kde.org
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  boost-devel
BuildRequires:  cmake(KF6CalendarCore) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6Runner) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6Parts) >= %{kf6_version}
BuildRequires:  cmake(KPim6Akonadi) >= %{kpim6_version}
BuildRequires:  cmake(KPim6AkonadiCalendar) >= %{kpim6_version}
BuildRequires:  cmake(KPim6KontactInterface) >= %{kpim6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  x86_64 %{x86_64} aarch64 riscv64

%description
Zanshin Todo is an application for managing your day-to-day actions.
It helps you organize and reduce the cognitive pressure of what one has to do in his
job and personal life. You will never forget anything anymore.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name}

%files
%license LICENSES/*
%doc README.md
%{_kf6_applicationsdir}/org.kde.zanshin.desktop
%{_kf6_appstreamdir}/org.kde.zanshin.metainfo.xml
%{_kf6_bindir}/zanshin
%{_kf6_bindir}/zanshin-migrator
%{_kf6_iconsdir}/hicolor/*/apps/zanshin.png
%{_kf6_iconsdir}/hicolor/scalable/apps/zanshin.svgz
%dir %{_kf6_plugindir}/kf6/krunner
%{_kf6_plugindir}/kf6/krunner/org.kde.zanshin.so
%dir %{_kf6_plugindir}/pim6
%dir %{_kf6_plugindir}/pim6/kontact
%{_kf6_plugindir}/pim6/kontact/kontact_zanshinplugin.so
%{_kf6_plugindir}/zanshin_part.so

%files lang -f %{name}.lang

%changelog
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- No code change since 25.03.90
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- Changes since 24.12.3:
  * Remove FeatureSummary as we use ECMFeatureSummary
  * Stripping .desktop suffix from legacy AppStream ID.
  * Fix variable: use QT_REQUIRED_VERSION
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- No code change since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Prepare windows build support
  * Fix concurrency queries, similar to previous commit
  * Fix doubled projects after unchecking and checking again a data source
  * akonadilivequeryhelperstest: factorize duplicated code
  * const'ify pointer
  * use nullptr
  * Make compile with new api
  * setDynamicSortFilter is true by default
  * Add qDebug support to domain objects (and their sharedptrs)
  * Remove unused includes, detected by clangd in vscode
  * Show contexts in non-context pages, as 'bubbles'
  * Fix warning when deleting the currently running task
  * Fix syntax in kde-ci.yml: failing tests still weren't failing CI
  * Adapt pageviewtest after commit "Update main view to be more frameless"
  * Port away from deprecated qSetGlobalQHashSeed
  * Fix obvious typo, gcc warned about use of null pointer
  * .reuse file didn't need license but REUSE.toml needs it
  * Convert .reuse/dep5 to REUSE.toml
  * Actually initialize KCrash
  * Remove virtual keyword when we use override
  * Add kcrash support
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * Fix concurrency queries, similar to previous commit
  * Fix doubled projects after unchecking and checking again a data source
  * akonadilivequeryhelperstest: factorize duplicated code
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * Use @info:placeholder
  * Add developer name and launchable to appdata
  * Update main view to be more frameless
  * Add build-ftime support
  * Use i18n context
  * It compiles fine without deprecated kf methods
  * Keep only src/ for the code coverage evaluation
  * Make sure failing tests are failing the CI again
  * Delay a bit after the expose event
  * Make sure a qWait happens after a setFocus
  * Use qWaitForWindowExposed
  * Make sure we always get collections/contexts/items in same order
  * Fix typing error
  * Fix the auto tests for features
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * Use desktop-application
  * Add vcs-browser
  * Drop support for KF5's deprecated KToolInvocation
  * QtTestGui is not necessary
  * Avoid to include QtTest (which loads a lot of includes)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- No code change since 24.02.0
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Fri Dec 15 2023 Christophe Marin <christophe@krop.fr>
- Require extra-cmake-modules at build time
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Mark some parts as title
  * Add feature from website to appstream description
  * Remove CI 6 job. We will use kf6 branch for kf6 works
  * Make compile against last kf6
  * Add Qt6 CI
  * Allow building against KF6
  * Adapt to KF6 KRunner changes
  * Replace KCalCore with KCalendarCore
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Tune the SVG to avoid the black rectangle of doom with QtSvgRenderer
  * Add CI
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Install translations
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80.
  * New feature release
- Drop obsolete patches:
  * Install-the-kontact-plugin-into-kontact5.patch
  * Port-to-kontactinterface-5.14.42.patch
* Tue Apr 20 2021 Christophe Giboudeaux <christophe@krop.fr>
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Jan 15 2021 Simon Lees <simonf.lees@suse.com>
- %%make_jobs to %%cmake_build
- use %%autosetup
* Thu Jul 23 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patches to fix build with kontactinterface 20.08:
  * Port-to-kontactinterface-5.14.42.patch
  * Install-the-kontact-plugin-into-kontact5.patch
* Thu Feb  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.5.71. No changelog.
- Drop upstream patches:
  * 0001-Fix-compilation-with-latest-KCalCore-API-changes-Att.patch
  * 0001-Fix-build-with-Boost-1.70.0.patch
  * 0001-Look-for-AkonadiContact.patch
  * 0001-Remove-the-delegation-feature.patch
  * 0001-Fix-compilation-after-Collection-referenced-was-removed.patch
  * 0001-Fix-linking-of-the-cuke-steps.patch
  * 0001-Make-it-build-both-with-pre-and-post.patch
* Thu Oct 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix the license tag. Zanshin has GPL-2.0-only and MIT files
* Fri Oct 11 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add patches to build with recent kcalendarcore versions:
  * 0001-Fix-compilation-with-latest-KCalCore-API-changes-Att.patch
  * 0001-Fix-build-with-Boost-1.70.0.patch
  * 0001-Look-for-AkonadiContact.patch
  * 0001-Remove-the-delegation-feature.patch
  * 0001-Fix-compilation-after-Collection-referenced-was-removed.patch
  * 0001-Fix-linking-of-the-cuke-steps.patch
  * 0001-Make-it-build-both-with-pre-and-post.patch
- Drop patches:
  * findKF5sooner.patch
  * useknownGCCflag.patch
  * qpointerconnect.diff
  * fix-build-with-Qt-5.6.patch
* Wed Jun 19 2019 wbauer@tmo.at
- Update findKF5sooner.patch: find AkonadiContact too to fix build
  with latest KDE Applications
* Thu Jan  4 2018 wbauer@tmo.at
- Update to 0.5.0
  * Errors coming from the system are now displayed properly in the
    main window
  * Tasks scheduled in the future can be filtered out
  * A task can be picked up as the "currently running" showing a
    nice overlay at the top of the screen, this is a reminder of
    what you're supposed to focus on
  * Projects are now displayed grouped by their containing
    collection which can help separate better visually between work
    and personal projects
  * Attachments are now supported for tasks (which nicely complete
    the "create todo" feature from KMail)
  * Tasks with recurrence are now supported (although we have a
    simple recurrence model for now)
  * And of course also a couple of minor GUI adjustments and bug
    fixes
  Under the hood, we also did some improvements:
  * Some error handling has been improved
  * Some duplicated code has been factorized
  * Some dead code has been cleaned up
  * Issues pointed out by krazy and clazy have been addressed
  * Feature level tests have been reworked and are better insulated
    from each other
  * Our code related to dates have been ported to the new KCalCore
    ABI introduced in 17.12
  * The biggest architectural change has been the introduction of a
    cache which speeds up our accesses to akonadi and allowed to
    address a few bugs (we had some views exhibiting duplicated
    items, this is now gone)
- Adjust build requirements
- Add -lang subpackage that contains translations
- Add fix-build-with-Qt-5.6.patch to make it build on Leap 42.x
- Update qpointerconnect.diff to fix another instance of the same
  "problem" and make it build with gcc 4.8 again
- Update source URL
* Fri Feb  3 2017 jengelh@inai.de
- Trim filler phrases from description.
* Mon Nov 21 2016 lbeltrame@kde.org
- Remove not needed requirement on gcc5
* Sun Nov 20 2016 mailaender@opensuse.org
- adhere to https://spdx.org/licenses/
* Tue Sep  6 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.4.1
* Tue Apr 19 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.4.0
* Sat Apr  9 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.3.91
* Sat Apr  2 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.3.81
* Tue Jan 12 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.3.1
* Fri Jan  1 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.3.0
* Thu Dec 24 2015 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.2.91
* Wed Dec 16 2015 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.2.80
* Thu Jan  8 2015 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.2.2
* Wed Aug  8 2012 cgiboudeaux@gmx.com
- Update translations
- Spec cleanup
* Mon Oct  3 2011 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.2rc1
* Wed Aug 31 2011 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.2beta2
* Tue Aug  2 2011 cgiboudeaux@gmx.com
- Add translations
* Wed Jul 27 2011 cgiboudeaux@gmx.com
- Spec cleanup, fixed some rpmlint warnings
* Mon Jul 18 2011 Kevin Ottens <ervin@kde.org>
- upgrading to 0.2beta1
* Tue May 10 2011 Kevin Ottens <ervin@kde.org>
- upgrading to 0.2alpha2
* Mon Feb  7 2011 Kevin Ottens <ervin@kde.org>
- Spec cleanup, fixed some rpmlint warnings
* Wed Oct 14 2009 Kevin Ottens <ervin@kde.org>
- upgrading to latest svn
* Fri Jan 30 2009 Kevin Ottens <ervin@kde.org>
- first packaging
